@@ -1,8 +1,8 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2011 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
@@ -20,7 +20,6 @@
 
 #include "Transport.h"
 
-#include "ReadBuffer.h"
 #include "WriteBuffer.h"
 
 #include "OpcodeStore.h"
@@ -65,7 +64,7 @@ class StaticCompressor;
 typedef enum
 {
   channel_none = -1,
-  channel_x,
+  channel_x11,
   channel_cups,
   channel_smb,
   channel_media,
@@ -83,18 +82,11 @@ typedef enum
 
 typedef enum
 {
-  notify_begin_congestion,
-  notify_end_congestion,
-  notify_begin_synchronization,
-  notify_end_synchronization,
-  notify_begin_reset,
-  notify_end_reset,
   notify_no_split,
   notify_start_split,
   notify_commit_split,
   notify_end_split,
   notify_empty_split,
-  notify_need_flush
 
 } T_notification_type;
 
@@ -118,7 +110,8 @@ class Channel
   // buffer.
   //
 
-  virtual int handleRead(EncodeBuffer &encodeBuffer) = 0;
+  virtual int handleRead(EncodeBuffer &encodeBuffer, const unsigned char *message,
+                             unsigned int length) = 0;
 
   //
   // Decode any X message encoded in the
@@ -158,7 +151,13 @@ class Channel
 
   virtual int handleFinish() = 0;
 
-  virtual int handleNotify(T_notification_type type) = 0;
+  //
+  // Interleave reads of the available
+  // events while writing data to the
+  // channel socket.
+  //
+
+  virtual int handleAsyncEvents() = 0;
 
   //
   // Handle the channel tear down.
@@ -196,50 +195,18 @@ class Channel
   int handleDrain(int timeout, int limit);
 
   //
-  // Model the generation of congestion events
-  // triggered by the channel overload.
+  // Flush any remaining data in the transport
+  // buffer.
   //
 
-  int needCongestion()
-  {
-    if (congestion_ != isCongested())
-    {
-      //
-      // Update the congestion flag and tell
-      // the proxy to send a new congestion
-      // message to the remote end.
-      //
+  int handleFlush();
 
-      congestion_ = !congestion_;
+  //
+  // Called when the loop has replaced or
+  // closed a previous alert.
+  //
 
-      #if defined(TEST) || defined(INFO)
-
-      if (congestion_ == 1)
-      {
-        *logofs << "handleCongestion: Channel for FD#" << fd_
-                << " is in congestion state.\n"
-                << logofs_flush;
-      }
-      else
-      {
-        *logofs << "handleCongestion: Channel for FD#" << fd_
-                << " is out of congestion state.\n"
-                << logofs_flush;
-      }
-
-      #endif
-
-      return 1;
-    }
-
-    #ifdef TEST
-    *logofs << "handleCongestion: No change reported in "
-            << "congestion state for FD#" << fd_
-            << ".\n" << logofs_flush;
-    #endif
-
-    return 0;
-  }
+  void handleResetAlert();
 
   //
   // Initialize all the static members.
@@ -291,18 +258,6 @@ class Channel
 
   virtual int needMotion() const = 0;
 
-  //
-  // Check channel's own buffer size.
-  //
-
-  virtual int needLimit() const = 0;
-
-  //
-  // Return the maximum buffer size.
-  //
-
-  virtual int getLimit() const = 0;
-
   //
   // Return the type of traffic carried
   // by this channel.
@@ -310,29 +265,6 @@ class Channel
 
   virtual T_channel_type getType() const = 0;
 
-  //
-  // Return the sequence number of the
-  // last request encoded or decoded,
-  // if this is an X channel. Used to
-  // implement synchronization between
-  // proxies.
-  //
-
-  virtual int getClientSequence() const
-  {
-    return -1;
-  }
-
-  virtual int getServerSequence() const
-  {
-    return -1;
-  }
-
-  virtual int getRequest() const
-  {
-    return -1;
-  }
-
   //
   // Check if the channel has been marked
   // as closing down.
@@ -353,35 +285,6 @@ class Channel
     return drop_;
   }
 
-  //
-  // Check if we left messages in the 
-  // read buffer.
-  //
-
-  int getPending() const
-  {
-    #ifdef TEST
-    *logofs << "Channel: Buffer for X descriptor FD#"
-            << fd_ << " has " << transport_ -> pending()
-            << " bytes to read and pending flag "
-            << pending_ << ".\n" << logofs_flush;
-    #endif
-
-    return pending_;
-  }
-
-  void setPending()
-  {
-    #ifdef TEST
-    *logofs << "Channel: Buffer for X descriptor FD#"
-            << fd_ << " set to be pending with "
-            << transport_ -> pending() << " bytes "
-            << "to read.\n" << logofs_flush;
-    #endif
-
-    pending_ = 1;
-  }
-
   int getCongestion()
   {
     return congestion_;
@@ -389,15 +292,12 @@ class Channel
 
   protected:
 
-  int handleStartup(MessageStore *store, const int position);
-
   int handleFlush(T_flush type)
   {
     //
     // We could write the data immediately if there
     // is already something queued to the low level
-    // TCP buffers. It must be better evaluated if
-    // this provides any benefit.
+    // TCP buffers.
     //
     // if (... || transport_ -> queued() > 0)
     // {
@@ -408,7 +308,7 @@ class Channel
     if (writeBuffer_.getScratchLength() > 0 ||
           (type == flush_if_any && writeBuffer_.getLength() > 0) ||
               writeBuffer_.getLength() >= (unsigned int)
-                  control -> TransportWriteThreshold)
+                  control -> TransportFlushBufferSize)
     {
       return handleFlush(type, writeBuffer_.getLength(),
                              writeBuffer_.getScratchLength());
@@ -417,6 +317,19 @@ class Channel
     return 0;
   }
 
+  //
+  // Actually flush the data to the
+  // channel descriptor.
+  //
+
+  int handleFlush(T_flush type, int bufferLength, int scratchLength);
+
+  //
+  // Handle the congestion changes.
+  //
+
+  int handleCongestion();
+
   //
   // Encode and decode X messages.
   //
@@ -487,7 +400,7 @@ class Channel
   void handleUpdate(MessageStore *store, const unsigned int dataSize,
                         const unsigned int compressedDataSize)
   {
-    if (store -> lastAction == is_added)
+    if (store -> lastAction == IS_ADDED)
     {
       handleUpdateAdded(store, dataSize, compressedDataSize);
     }
@@ -497,7 +410,7 @@ class Channel
                       const unsigned char *compressedData = NULL,
                           const unsigned int compressedDataSize = 0)
   {
-    if (store -> lastAction == is_added)
+    if (store -> lastAction == IS_ADDED)
     {
       handleSaveAdded(store, 0, buffer, size, compressedData, compressedDataSize);
     }
@@ -506,7 +419,7 @@ class Channel
   void handleSaveSplit(MessageStore *store, unsigned char *buffer,
                           unsigned int size)
   {
-    if (store -> lastAction == is_added)
+    if (store -> lastAction == IS_ADDED)
     {
       return handleSaveAdded(store, 1, buffer, size, 0, 0);
     }
@@ -548,14 +461,17 @@ class Channel
                                     unsigned int &size);
 
   //
-  // Model notification of congestion
-  // events.
+  // X11 channels are considered to be in
+  // congestion state when there was a
+  // blocking write and, since then, the
+  // local end didn't consume all the data.
   //
 
   virtual int isCongested()
   {
-    return (transport_ -> length() >
-                control -> TransportXBufferLimit);
+    return (transport_ -> getType() !=
+                transport_agent && transport_ -> length() >
+                    control -> TransportFlushBufferSize);
   }
 
   virtual int isReliable()
@@ -564,8 +480,9 @@ class Channel
   }
 
   //
-  // Establish rules on how to handle allocation
-  // of new messages in the message stores.
+  // Determine how to handle allocation
+  // of new messages in the message
+  // stores.
   //
 
   int mustCleanStore(MessageStore *store)
@@ -581,22 +498,15 @@ class Channel
 
   int canCleanStore(MessageStore *store)
   {
-    return (store -> getSize() > 0 && (store -> getRemoteStorageSize() >
+    return ((store -> getSize() > 0 && (store -> getRemoteStorageSize() >
                 (control -> RemoteTotalStorageSize / 100 * store ->
-                    cacheLowerThreshold)) || (store -> getLocalStorageSize() >
+                    cacheLowerThreshold))) || (store -> getLocalStorageSize() >
                         (control -> LocalTotalStorageSize / 100 *  store ->
                             cacheLowerThreshold)));
   }
 
   protected:
 
-  //
-  // Actually flush the data to the
-  // channel descriptor.
-  //
-
-  int handleFlush(T_flush type, int bufferLength, int scratchLength);
-
   //
   // Set up the split stores.
   //
@@ -701,10 +611,11 @@ class Channel
   int finish_;
   int closing_;
   int drop_;
-  int pending_;
   int congestion_;
   int priority_;
 
+  int alert_;
+
   //
   // It will be set to the descriptor of the
   // first X channel that is successfully con-
@@ -730,13 +641,6 @@ class Channel
   int enableSave_;
   int enableLoad_;
 
-  //
-  // Cache status of last 'keep' operation
-  // on message stores.
-  //
-
-  static int enableKeep_;
-
   //
   // Keep track of object creation and
   // deletion.
