@@ -1,8 +1,8 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2011 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
@@ -46,6 +46,8 @@
 #define FILLPOLY_CACHE_THRESHOLD            3
 #define FILLPOLY_CACHE_LOWER_THRESHOLD      1
 
+#define FILLPOLY_DATA_OFFSET_IF_PROTO_STEP_8    20
+
 //
 // The message class.
 //
@@ -75,6 +77,9 @@ class FillPolyMessage : public Message
   unsigned char mode;
   unsigned int  drawable;
   unsigned int  gcontext;
+
+  unsigned short x_origin;
+  unsigned short y_origin;
 };
 
 class FillPolyStore : public MessageStore
@@ -95,6 +100,11 @@ class FillPolyStore : public MessageStore
     dataLimit  = FILLPOLY_DATA_LIMIT;
     dataOffset = FILLPOLY_DATA_OFFSET;
 
+    if (control -> isProtoStep8() == 1)
+    {
+      dataOffset = FILLPOLY_DATA_OFFSET_IF_PROTO_STEP_8;
+    }
+
     cacheSlots          = FILLPOLY_CACHE_SLOTS;
     cacheThreshold      = FILLPOLY_CACHE_THRESHOLD;
     cacheLowerThreshold = FILLPOLY_CACHE_LOWER_THRESHOLD;
@@ -157,6 +167,15 @@ class FillPolyStore : public MessageStore
     delete (FillPolyMessage *) message;
   }
 
+  virtual int identitySize(const unsigned char *buffer, unsigned int size)
+  {
+    unsigned int offset = (control -> isProtoStep8() == 1 ?
+                               FILLPOLY_DATA_OFFSET_IF_PROTO_STEP_8 :
+                                   FILLPOLY_DATA_OFFSET);
+
+    return (size >= offset ? offset : size);
+  }
+
   virtual int parseIdentity(Message *message, const unsigned char *buffer,
                                 unsigned int size, int bigEndian) const;
 
