@@ -1,6 +1,6 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2011 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
 /* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
@@ -9,7 +9,7 @@
 /*                                                                        */
 /* Check http://www.nomachine.com/licensing.html for applicability.       */
 /*                                                                        */
-/* NX and NoMachine are trademarks of NoMachine S.r.l.                    */
+/* NX and NoMachine are trademarks of Medialogic S.p.A.                   */
 /*                                                                        */
 /* All rights reserved.                                                   */
 /*                                                                        */
@@ -21,7 +21,7 @@
 // that they can also work on Windows.
 //
 
-FILE *Popen(char * const parameters[], const char *type);
-FILE *Popen(const char *command, const char *type);
+extern FILE *Popen(char * const parameters[], const char *type);
+extern FILE *Popen(const char *command, const char *type);
 
-int Pclose(FILE *file);
+extern int Pclose(FILE *file);
