@@ -1,8 +1,8 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2011 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
@@ -64,7 +64,7 @@ int SendEventStore::parseIdentity(Message *message, const unsigned char *buffer,
            << this << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 int SendEventStore::unparseIdentity(const Message *message, unsigned char *buffer,
@@ -93,7 +93,7 @@ int SendEventStore::unparseIdentity(const Message *message, unsigned char *buffe
           << this << ".\n" << logofs_flush;
   #endif
 
-  return true;
+  return 1;
 }
 
 void SendEventStore::dumpIdentity(const Message *message) const
